==> py3-tagpy-2013.1p16.tgz: lib/python3.9/site-packages/tagpy/id3v1.py <==
# Copyright (c) 2006-2008 Andreas Kloeckner
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.




import _tagpy




def _genreList():
    result = []
    i = 0
    next = _tagpy.id3v1_genre(i)
    while next:
        result.append(next)
        i += 1
        next = _tagpy.id3v1_genre(i)
    return result

_GenreList = _genreList()
_GenreMap = dict([(v, k) for k, v in enumerate(_GenreList)])

genre = _tagpy.id3v1_genre
def genreIndex(genre): return _GenreMap[genre]
def genreList(): return _GenreList
def genreMap(): return _GenreMap

==> py3-tagpy-2025.1p0.tgz: lib/python3.12/site-packages/tagpy/id3v1.py <==
# Copyright (c) 2006-2008 Andreas Kloeckner
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import _tagpy


def _genreList():
    result = []
    i = 0
    next = _tagpy.id3v1_genre(i)
    while next:
        result.append(next)
        i += 1
        next = _tagpy.id3v1_genre(i)
    return result


_GenreList = _genreList()
_GenreMap = dict([(v, k) for k, v in enumerate(_GenreList)])

genre = _tagpy.id3v1_genre


def genreIndex(genre):
    return _GenreMap[genre]


def genreList():
    return _GenreList


def genreMap():
    return _GenreMap
